@@ -2,8 +2,7 @@
 
 # Note(TheJulia): We should proceed with attempting to collect information
 # even if a command fails, and as such set -e should not be present.
-set -ux
-set -o pipefail
+set -uxo pipefail
 
 # Note(TheJulia): If there is a workspace variable, we want to utilize that as
 # the preference of where to put logs
@@ -48,6 +47,11 @@ if $(sudo iptables --version &>/dev/null); then
         done
     fi
 fi
+
+if $(sudo firewall-cmd --version &>/dev/null); then
+    sudo firewall-cmd --list-all-zones &> ${LOG_LOCATION}/firewalld-zones.log
+fi
+
 if $(ip link &>/dev/null); then
     ip -s link &> ${LOG_LOCATION}/interface_counters.log
 fi
